<?php

namespace App\Http\Controllers;

use App\Models\Cart;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class CartController extends Controller
{
    public function __construct() {
        parent::__construct();
        $this->middleware(['auth', 'verified']);
    }

    public function index() 
    {  
        $might_also_like = Product::mightAlsoLike()->get();
        return view('shop-cart', compact('might_also_like'));
    }

    public function store(Request $request)
    {
        $product = Product::where('slug', '=', $request->product_slug)->first();
        
        $duplicates = Cart::query()
                ->where('user_id', Auth::user()->id)
                ->where('product_id', $product->id)
                ->get();
        

        if ($duplicates->count() > 0) 
        {
            return response('error');
        }
        else 
        {
            $cart = new Cart();
            $cart->product_id = $product->id;
            $cart->user_id = Auth::user()->id;

            if($product->on_sale)
            {
                $cart->price = $product->on_sale*$request->quantity;
            }
            else
            {
                $cart->price = $product->price*$request->quantity;
            }
            $cart->quantity = $request->quantity;
            $cart->save();
            $qty=$request->quantity;
            $cartId=$cart->id;
            $tot =auth()->user()->cart->sum('price');
            $cart_count = auth()->user()->cart->sum('quantity');
           return response()->json(['cart_count'=>$cart_count,'product'=>$product,'qty'=>$qty,'total'=>$tot,'cart'=>$cartId]);
        }
    }

    public function update(Request $request)
    {
        Cart::where('id', $request->id)
                ->update([
                        'quantity' => $request->quantity,
                        'price'    =>$request->price*$request->quantity
                        ]);
                
        session()->flash('success_message', 'Quantity was updated successfully');
        return back();
    }

    public function destroy($id) 
    {
        $cart = Cart::where('id', '=', $id)->first();
        $cart->delete();
        return back()->with('success_message', 'Item has been removed!');
    }
}
