<?php

namespace App\Http\Controllers;

use App\Models\Cart;
use App\Models\Order;
use App\Mail\OrderMail;
use App\Models\Product;
use App\Mail\OrderReceived;
use App\Models\OrderProduct;
use Illuminate\Http\Request;
use TCG\Voyager\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Session;

class CheckoutController extends Controller
{
    public function __construct() {
        parent::__construct();
        $this->middleware(['auth', 'verified']);
    }
    
    public function index()
    {
        $cart = Cart::orderBy('created_at', 'asc')->where('user_id', '=', Auth::id())->get();
        return view('checkout', compact('cart'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required',
            'address' => 'required',
            'city' => 'required',
            'phone' => 'required|max:8',
        ]);
        $carts = Cart::orderBy('created_at', 'asc')->where('user_id', '=', Auth::id())->get();

        $sub_total = $carts->sum('price');
        $delivery_fee=setting('tax.fee') ?? 2.00;

        $order = new Order();
        $order->user_id = Auth::id();
        $order->name = $request['name'];
        $order->email = $request['email'];
        $order->address = $request['address'];
        $order->city = $request['city'];
        $order->street = $request['street'];
        $order->building_and_floor = $request['building-floor'];
        $order->phone = $request['phone'];
        $order->additional_comments = $request['additional_comments'];
        $order->subtotal=$sub_total;
        $order->delivery_fee=$delivery_fee;
        $order->order_total = $sub_total + $delivery_fee;
        $order->status = 'Processing';

        foreach ($carts as $item) {
            $product = Product::find($item->product->id);
            $product->decrement('quantity', $item->quantity);
        }

        if($order->save())
        {
            $user = User::where('id', '=', Auth()->user()->id)->first();
            $user->city = $order->city;
            $user->street = $order->street;
            $user->building_and_floor = $order->building_and_floor;
            if($user->mobile == NULL)
            {
                $user->mobile = $order->phone;
            }
            $user->save();
            foreach ($carts as $item) {
                OrderProduct::create([
                    'order_id' => $order->id,
                    'product_id' => $item->product->id,
                    'quantity' => $item->quantity,
                    'price' => $item->price,

                ]);
            }
            Cart::where('user_id', '=', Auth::user()->id)->delete();
            Mail::to(setting('site.email'))->send(new OrderMail( $order));
            Mail::to($order->email)->send(new OrderReceived($order));
            Session::flash('success_message', 'Thank you, Your order has been successfully placed!');
        }
        else
        {
            Session::flash('error', 'Error lacing order. Please try again later.');
        }
        return redirect()->route('home');
    }
}
