<?php

namespace App\Http\Controllers;

use App\Models\News;
use App\Models\Brand;
use App\Mail\ContactUs;
use App\Models\Contact;
use App\Models\Product;
use App\Models\Service;
use App\Models\Download;
use App\Models\FaqCategory;
use Illuminate\Http\Request;
use TCG\Voyager\Models\Page;
use App\Models\ProductCategory;
use App\Models\DownloadCategory;
use Illuminate\Support\Facades\Mail;

class PageController extends Controller
{
    public function __construct()
    {
        parent::__construct();
    }

    public function home()
    {
        $brands = Brand::all();
        $random_services = Service::take(3)->inRandomOrder()->get();
        $categories = ProductCategory::orderBy('created_at', 'asc')->limit(5)->get();
        return view('welcome', compact('brands', 'random_services', 'categories'));
    }

    public function service($slug)
    {
        $service = Service::where('slug', $slug)->first();
        return view('service-details', compact('service'));
    }

    public function about_us()
    {
        $about = Page::where('slug', 'about-us')->first();
        return view('about_us', compact('about'));
    }

    public function news()
    {
        $news = News::orderBy('created_at', 'DESC')->paginate(9);
        return view('news', compact('news'));
    }

    public function news_details($slug)
    {
        $news = News::where('slug', $slug)->first();
        $categories = ProductCategory::orderBy('order', 'ASC')->get();
        $all_news = News::orderBy('created_at', 'desc')->where('id', '!=', $news->id)->limit(3)->get();
        return view('news-details', compact('news', 'all_news','categories'));
    }

    public function product_categories($slug)
    {
        $category = ProductCategory::where('slug', $slug)->first();
        return view('product-category', compact('category'));
    }

    public function shop()
    {
        $products = Product::where('is_active', 1)->orderBy('created_at','Asc')->paginate(9);
        $categories = ProductCategory::orderBy('order', 'ASC')->get();
        return view('shop', compact('products', 'categories'));
    }

    public function product_details($slug)
    {
        $product = Product::where('slug', $slug)->first();
        $productCategoryId = $product->category->id;
        $relatedProducts = Product::inRandomOrder()->where('product_category_id', $productCategoryId)->where('id', '<>', $product->id)->where('is_active', 1)->limit(3)->get();
        return view('product-detail', compact('product', 'relatedProducts'));
    }

    public function itemDetails(Request $request)
	{
		$product = Product::findOrFail($request->get('item_id'));
		return view('details', compact('product'));
	}

    public function contact()
    {
        return view('contact');
    }

    public function sendContact(Request $request)
    {
        $request->validate([
            'fullname'    => 'required',
            'email'       => 'required',
            'phonenumber' => 'required',
            'companyname' => 'required',
            'message'     => 'required',
            'g-recaptcha-response' => 'required|captcha',

        ]);

        $contact = new Contact();

        $contact->fullname = $request->fullname;
        $contact->email = $request->email;
        $contact->phonenumber = $request->phonenumber;
        $contact->companyname = $request->companyname;
        $contact->message = $request->message;


        if ($contact->save())
        {
            Mail::to(setting('site.email'))->send(new ContactUs($contact));
            $request->session()->flash('success', "Thank you for reaching out! We'll get in touch as soon as possible.");
            return redirect()->back();
        }
    }

    public function faq()
    {
        $categories = FaqCategory::all();
        return view('faq', compact('categories'));
    }

    public function downloads()
    {
        $download_categories = DownloadCategory::all();
        return view('download', compact('download_categories'));
    }

    public function downloadFile(Request $request)
    {
        $download = Download::whereId($request['item_id'])->first();
        $download->download += 1;
        $download->save();
         return response('success');
    }

    public function search(Request $request)
    {
        $keyword =  $request->input('key');
        $products = Product::where('name', 'like', "%$keyword%")->orderBy('created_at', 'desc')->paginate(12);
        $products->appends(['key' => $keyword ]);
        return view('search', compact('products'));
    }

}
