<?php

namespace App\Http\Controllers;

use App\Models\Order;
use Carbon\Carbon;
use Illuminate\Http\Request;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class ProfileController extends Controller
{
    public function __construct()
    {
        parent::__construct();
        $this->middleware(['auth', 'verified']);
    }

    public function index()
    {
        $orders = auth()->user()->orders()->with('products')->get(); 
        return view('profile', compact('orders'));
    }
    public function orderDetails($id)
    {
        $order = Order::where('user_id',Auth::id())->whereId($id)->with('products')->first();
       return view('order',compact('order'));

    }

    public function update(Request $request, $id)
    {
        $user = User::findOrFail($id);
        $user->name = $request->get('name');
        $user->gender = $request->get('gender');
        if ($request->get('dob'))
        {
            $user->date_of_birth = Carbon::parse($request->get('dob'))->format('Y-m-d');
        }
        else
        {
            $user->date_of_birth = NULL;
        }
        
        $user->mobile = $request->get('phone');
        $user->save();
        return back()->with('success_message', 'Profile Updated Successfully!');
    }

    public function changePassword(Request $request)
    {
        if (!(Hash::check($request->get('current-password'), Auth::user()->password))) {
            // The passwords matches
            return redirect()->back()->with("error","Your current password does not matches with the password you provided. Please try again.");
        }
        if(strcmp($request->get('current-password'), $request->get('new-password')) == 0){
            //Current password and new password are same
            return redirect()->back()->with("error","New Password cannot be same as your current password. Please choose a different password.");
        }
        $validatedData = $request->validate([
            'current-password' => 'required',
            'new-password' => 'required|string|min:8|confirmed',
        ]);
        //Change Password
        $user = Auth::user();
        $user->password = bcrypt($request->get('new-password'));
        $user->save();

        return redirect()->back()->with("success","Password changed successfully !");
    }

    public function addressUpdate(Request $request, $id)
    {
        $user = User::findOrFail($id);
        $user->first_address = $request->get('first-address');
        $user->second_address = $request->get('second-address');
        $user->city = $request->get('city');
        $user->street = $request->get('street');
        $user->building_and_floor = $request->get('building-floor');
        if($user->save())
        {
            return back()->with('success_message', 'Addresses are Added Successfully!');
        }
    }
}
